# MDTerp


[![image](https://img.shields.io/pypi/v/MDTerp.svg)](https://pypi.python.org/pypi/MDTerp)
![MDTerp](./docs/MDTerp_logo.png)


**A python project for interpreting molecular dynamics trajectory metastable state classifications from machine-learning models**


-   Free software: MIT License
-   Documentation: https://shams-mehdi.github.io/MDTerp
    

## Features

-   (Test) Scans blackbox AI classifier models trained on MD data for feature importance.
  
## Installation

To install MDTerp, run this command in your terminal:

```
pip install MDTerp
```

This is the preferred method to install MDTerp, as it will always install the most recent stable release (https://pypi.org/project/MDTerp/).


## Demos

-   [Notebook 1](docs/examples/MDTerp_demo1.ipynb)
-   [Notebook 2](docs/examples/MDTerp_demo2.ipynb)
